import request from '@/utils/request'

// 查询企业信息审核列表
export function listApply(query) {
  return request({
    url: '/system/apply/list',
    method: 'get',
    params: query
  })
}

// 查询企业信息审核详细
export function getApply(id) {
  return request({
    url: '/system/apply/' + id,
    method: 'get'
  })
}

// 新增企业信息审核
export function addApply(data) {
  return request({
    url: '/system/apply',
    method: 'post',
    data: data
  })
}

// 修改企业信息审核
export function updateApply(data) {
  return request({
    url: '/system/apply/put',
    method: 'post',
    data: data
  })
}

// 删除企业信息审核
export function delApply(id) {
  return request({
    url: '/system/apply/' + id,
    method: 'delete'
  })
}
